#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
File: ai_solutions.py
Description: ai solutions for each theme API.
"""

ASPACE_API_KEY = ""
ASPACE_URL =""
#         Theme Sense
class sense:
    def sentiment_analysis(text):
        """Perform Sentiment analysis for a given text.
        Args:
            text: Text on which to perform sentiment analysis.

        Returns:
            An array of sentiment analysis and corresponding confidence factor.
        """
        return "sentiment analysis"


#         Theme Conversation
class conversation:
    def translate(text, from_lang, to_lang):
        """Perform translation for a given text.
                Args:
                    text: Text to be translated

                Returns:
                    An array of translated text , from_lang language, to_lang language
        """
        return "translate"




# !/usr/bin/env python
# -*- coding: utf-8 -*-
"""
File: __init__.py
Description: Python SDK of the aspace.ai API.
"""

#Version of ASpaceAI SDK
__version__ = "1.0.0"


from aspaceai.ai_solutions import *

